==> phoenix6-24.0.0b4-cp39-abi3-win_amd64.whl: phoenix6-24.0.0b4.data/purelib/phoenix6/controls/motion_magic_velocity_torque_current_foc.py <==
"""
Copyright (C) Cross The Road Electronics.  All rights reserved.
License information can be found in CTRE_LICENSE.txt
For support and suggestions contact support@ctr-electronics.com or file
an issue tracker at https://github.com/CrossTheRoadElec/Phoenix-Releases
"""

from phoenix6.phoenix_native import Native
from phoenix6.status_code import StatusCode
from phoenix6.units import *
import ctypes


class MotionMagicVelocityTorqueCurrentFOC:
    """
    Requests Motion Magic® to target a final velocity using a motion profile.  This
    allows smooth transitions between velocity set points.  Users can optionally
    provide a torque feedforward.
    
    Motion Magic® Velocity produces a motion profile in real-time while attempting
    to honor the specified Acceleration and Jerk value. If the specified
    acceleration is zero, the Acceleration under Motion Magic® configuration
    parameter is used instead. This allows for runtime adjustment of acceleration
    for advanced users.  Jerk is also specified in the Motion Magic® persistent
    configuration values.  If Jerk is set to zero, Motion Magic® will produce a
    trapezoidal acceleration profile.  Target velocity can also be changed
    on-the-fly and Motion Magic® will do its best to adjust the profile.  This
    control mode is based on torque current, so relevant closed-loop gains will use
    Amperes for the numerator.
    
    :param velocity:    Target velocity to drive toward in rotations per second. 
                        This can be changed on-the fly.
    :type velocity: rotations_per_second
    :param acceleration:    This is the absolute Acceleration to use generating the
                            profile.  If this parameter is zero, the Acceleration
                            persistent configuration parameter is used instead.
                            Acceleration is in rotations per second squared.  If
                            nonzero, the signage does not matter as the absolute
                            value is used.
    :type acceleration: rotations_per_second_squared
    :param enable_foc:    Set to true to use FOC commutation (requires Phoenix Pro),
                          which increases peak power by ~15%. Set to false to use
                          trapezoidal commutation.  FOC improves motor performance
                          by leveraging torque (current) control.  However, this may
                          be inconvenient for applications that require specifying
                          duty cycle or voltage.  CTR-Electronics has developed a
                          hybrid method that combines the performances gains of FOC
                          while still allowing applications to provide duty cycle or
                          voltage demand.  This not to be confused with simple
                          sinusoidal control or phase voltage control which lacks
                          the performance gains.
    :type enable_foc: bool
    :param feed_forward:    Feedforward to apply in torque current in Amperes.  User
                            can use motor's kT to scale Newton-meter to Amperes.
    :type feed_forward: ampere
    :param slot:    Select which gains are applied by selecting the slot.  Use the
                    configuration api to set the gain values for the selected slot
                    before enabling this feature. Slot must be within [0,2].
    :type slot: int
    :param override_coast_dur_neutral:    Set to true to coast the rotor when output
                                          is zero (or within deadband).  Set to
                                          false to use the NeutralMode configuration
                                          setting (default). This flag exists to
                                          provide the fundamental behavior of this
                                          control when output is zero, which is to
                                          provide 0A (zero torque).
    :type override_coast_dur_neutral: bool
    :param limit_forward_motion:    Set to true to force forward limiting.  This
                                    allows users to use other limit switch sensors
                                    connected to robot controller.  This also allows
                                    use of active sensors that require external
                                    power.
    :type limit_forward_motion: bool
    :param limit_reverse_motion:    Set to true to force reverse limiting.  This
                                    allows users to use other limit switch sensors
                                    connected to robot controller.  This also allows
                                    use of active sensors that require external
                                    power.
    :type limit_reverse_motion: bool
    """

    def __init__(self, velocity: rotations_per_second, acceleration: rotations_per_second_squared = 0.0, enable_foc: bool = True, feed_forward: ampere = 0.0, slot: int = 0, override_coast_dur_neutral: bool = False, limit_forward_motion: bool = False, limit_reverse_motion: bool = False):
        self._name = "MotionMagicVelocityTorqueCurrentFOC"
        self.update_freq_hz: hertz = 100.0
        
        self.velocity = velocity
        """
        Target velocity to drive toward in rotations per second.  This can be changed
        on-the fly.
        """
        self.acceleration = acceleration
        """
        This is the absolute Acceleration to use generating the profile.  If this
        parameter is zero, the Acceleration persistent configuration parameter is used
        instead. Acceleration is in rotations per second squared.  If nonzero, the
        signage does not matter as the absolute value is used.
        """
        self.enable_foc = enable_foc
        """
        Set to true to use FOC commutation (requires Phoenix Pro), which increases peak
        power by ~15%. Set to false to use trapezoidal commutation.  FOC improves motor
        performance by leveraging torque (current) control.  However, this may be
        inconvenient for applications that require specifying duty cycle or voltage. 
        CTR-Electronics has developed a hybrid method that combines the performances
        gains of FOC while still allowing applications to provide duty cycle or voltage
        demand.  This not to be confused with simple sinusoidal control or phase voltage
        control which lacks the performance gains.
        """
        self.feed_forward = feed_forward
        """
        Feedforward to apply in torque current in Amperes.  User can use motor's kT to
        scale Newton-meter to Amperes.
        """
        self.slot = slot
        """
        Select which gains are applied by selecting the slot.  Use the configuration api
        to set the gain values for the selected slot before enabling this feature. Slot
        must be within [0,2].
        """
        self.override_coast_dur_neutral = override_coast_dur_neutral
        """
        Set to true to coast the rotor when output is zero (or within deadband).  Set to
        false to use the NeutralMode configuration setting (default). This flag exists
        to provide the fundamental behavior of this control when output is zero, which
        is to provide 0A (zero torque).
        """
        self.limit_forward_motion = limit_forward_motion
        """
        Set to true to force forward limiting.  This allows users to use other limit
        switch sensors connected to robot controller.  This also allows use of active
        sensors that require external power.
        """
        self.limit_reverse_motion = limit_reverse_motion
        """
        Set to true to force reverse limiting.  This allows users to use other limit
        switch sensors connected to robot controller.  This also allows use of active
        sensors that require external power.
        """

    @property
    def name(self) -> str:
        """
        Gets the name of this control request.

        :returns: Name of the control request
        :rtype: str
        """
        return self._name

    def __str__(self) -> str:
        ss = []
        ss.append("class: MotionMagicVelocityTorqueCurrentFOC")
        ss.append("velocity: " + str(self.velocity))
        ss.append("acceleration: " + str(self.acceleration))
        ss.append("enable_foc: " + str(self.enable_foc))
        ss.append("feed_forward: " + str(self.feed_forward))
        ss.append("slot: " + str(self.slot))
        ss.append("override_coast_dur_neutral: " + str(self.override_coast_dur_neutral))
        ss.append("limit_forward_motion: " + str(self.limit_forward_motion))
        ss.append("limit_reverse_motion: " + str(self.limit_reverse_motion))
        return "\n".join(ss)

    def _send_request(self, network: str, device_hash: int, cancel_other_requests: bool) -> StatusCode:
        """
        Sends this request out over CAN bus to the device for
        the device to apply.

        :param network: Network to send request over
        :type network: str
        :param device_hash: Device to send request to
        :type device_hash: int
        :param cancel_other_requests: True to cancel other requests
        :type cancel_other_requests: bool
        :returns: Status of the send operation
        :rtype: StatusCode
        """

        return StatusCode(Native.instance().c_ctre_phoenix6_RequestControlMotionMagicVelocityTorqueCurrentFOC(ctypes.c_char_p(bytes(network, 'utf-8')), device_hash, self.update_freq_hz, cancel_other_requests, self.velocity, self.acceleration, self.enable_foc, self.feed_forward, self.slot, self.override_coast_dur_neutral, self.limit_forward_motion, self.limit_reverse_motion))

    
    def with_velocity(self, new_velocity: rotations_per_second) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's velocity parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_velocity: Parameter to modify
        :type new_velocity: rotations_per_second
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.velocity = new_velocity
        return self
    
    def with_acceleration(self, new_acceleration: rotations_per_second_squared) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's acceleration parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_acceleration: Parameter to modify
        :type new_acceleration: rotations_per_second_squared
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.acceleration = new_acceleration
        return self
    
    def with_enable_foc(self, new_enable_foc: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's enable_foc parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_enable_foc: Parameter to modify
        :type new_enable_foc: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.enable_foc = new_enable_foc
        return self
    
    def with_feed_forward(self, new_feed_forward: ampere) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's feed_forward parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_feed_forward: Parameter to modify
        :type new_feed_forward: ampere
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.feed_forward = new_feed_forward
        return self
    
    def with_slot(self, new_slot: int) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's slot parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_slot: Parameter to modify
        :type new_slot: int
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.slot = new_slot
        return self
    
    def with_override_coast_dur_neutral(self, new_override_coast_dur_neutral: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's override_coast_dur_neutral parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_override_coast_dur_neutral: Parameter to modify
        :type new_override_coast_dur_neutral: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.override_coast_dur_neutral = new_override_coast_dur_neutral
        return self
    
    def with_limit_forward_motion(self, new_limit_forward_motion: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's limit_forward_motion parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_limit_forward_motion: Parameter to modify
        :type new_limit_forward_motion: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.limit_forward_motion = new_limit_forward_motion
        return self
    
    def with_limit_reverse_motion(self, new_limit_reverse_motion: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's limit_reverse_motion parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_limit_reverse_motion: Parameter to modify
        :type new_limit_reverse_motion: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.limit_reverse_motion = new_limit_reverse_motion
        return self

    def with_update_freq_hz(self, new_update_freq_hz: hertz) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Sets the period at which this control will update at.
        This is designated in Hertz, with a minimum of 20 Hz
        (every 50 ms) and a maximum of 1000 Hz (every 1 ms).

        If this field is set to 0 Hz, the control request will
        be sent immediately as a one-shot frame. This may be useful
        for advanced applications that require outputs to be
        synchronized with data acquisition. In this case, we
        recommend not exceeding 50 ms between control calls.

        :param new_update_freq_hz: Parameter to modify
        :type new_update_freq_hz: hertz
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.update_freq_hz = new_update_freq_hz
        return self

    @property
    def control_info(self) -> dict:
        """
        Gets information about this control request.

        :returns: Dictonary of control parameter names and corresponding applied values
        :rtype: dict
        """
        control_info = {}
        control_info["name"] = self._name
        control_info["velocity"] = self.velocity
        control_info["acceleration"] = self.acceleration
        control_info["enable_foc"] = self.enable_foc
        control_info["feed_forward"] = self.feed_forward
        control_info["slot"] = self.slot
        control_info["override_coast_dur_neutral"] = self.override_coast_dur_neutral
        control_info["limit_forward_motion"] = self.limit_forward_motion
        control_info["limit_reverse_motion"] = self.limit_reverse_motion
        return control_info

==> phoenix6-24.2.0-cp39-abi3-win_amd64.whl: phoenix6-24.2.0.data/purelib/phoenix6/controls/motion_magic_velocity_torque_current_foc.py <==
"""
Copyright (C) Cross The Road Electronics.  All rights reserved.
License information can be found in CTRE_LICENSE.txt
For support and suggestions contact support@ctr-electronics.com or file
an issue tracker at https://github.com/CrossTheRoadElec/Phoenix-Releases
"""

from phoenix6.phoenix_native import Native
from phoenix6.status_code import StatusCode
from phoenix6.units import *
import ctypes


class MotionMagicVelocityTorqueCurrentFOC:
    """
    Requests Motion Magic® to target a final velocity using a motion profile.  This
    allows smooth transitions between velocity set points.  Users can optionally
    provide a torque feedforward.
    
    Motion Magic® Velocity produces a motion profile in real-time while attempting
    to honor the specified Acceleration and Jerk value. This control mode does not
    use the CruiseVelocity, Expo_kV, or Expo_kA configs. If the specified
    acceleration is zero, the Acceleration under Motion Magic® configuration
    parameter is used instead. This allows for runtime adjustment of acceleration
    for advanced users.  Jerk is also specified in the Motion Magic® persistent
    configuration values.  If Jerk is set to zero, Motion Magic® will produce a
    trapezoidal acceleration profile.  Target velocity can also be changed
    on-the-fly and Motion Magic® will do its best to adjust the profile.  This
    control mode is based on torque current, so relevant closed-loop gains will use
    Amperes for the numerator.
    
    :param velocity:    Target velocity to drive toward in rotations per second. 
                        This can be changed on-the fly.
    :type velocity: rotations_per_second
    :param acceleration:    This is the absolute Acceleration to use generating the
                            profile.  If this parameter is zero, the Acceleration
                            persistent configuration parameter is used instead.
                            Acceleration is in rotations per second squared.  If
                            nonzero, the signage does not matter as the absolute
                            value is used.
    :type acceleration: rotations_per_second_squared
    :param enable_foc:    Set to true to use FOC commutation (requires Phoenix Pro),
                          which increases peak power by ~15%. Set to false to use
                          trapezoidal commutation.  FOC improves motor performance
                          by leveraging torque (current) control.  However, this may
                          be inconvenient for applications that require specifying
                          duty cycle or voltage.  CTR-Electronics has developed a
                          hybrid method that combines the performances gains of FOC
                          while still allowing applications to provide duty cycle or
                          voltage demand.  This not to be confused with simple
                          sinusoidal control or phase voltage control which lacks
                          the performance gains.
    :type enable_foc: bool
    :param feed_forward:    Feedforward to apply in torque current in Amperes.  User
                            can use motor's kT to scale Newton-meter to Amperes.
    :type feed_forward: ampere
    :param slot:    Select which gains are applied by selecting the slot.  Use the
                    configuration api to set the gain values for the selected slot
                    before enabling this feature. Slot must be within [0,2].
    :type slot: int
    :param override_coast_dur_neutral:    Set to true to coast the rotor when output
                                          is zero (or within deadband).  Set to
                                          false to use the NeutralMode configuration
                                          setting (default). This flag exists to
                                          provide the fundamental behavior of this
                                          control when output is zero, which is to
                                          provide 0A (zero torque).
    :type override_coast_dur_neutral: bool
    :param limit_forward_motion:    Set to true to force forward limiting.  This
                                    allows users to use other limit switch sensors
                                    connected to robot controller.  This also allows
                                    use of active sensors that require external
                                    power.
    :type limit_forward_motion: bool
    :param limit_reverse_motion:    Set to true to force reverse limiting.  This
                                    allows users to use other limit switch sensors
                                    connected to robot controller.  This also allows
                                    use of active sensors that require external
                                    power.
    :type limit_reverse_motion: bool
    """

    def __init__(self, velocity: rotations_per_second, acceleration: rotations_per_second_squared = 0.0, enable_foc: bool = True, feed_forward: ampere = 0.0, slot: int = 0, override_coast_dur_neutral: bool = False, limit_forward_motion: bool = False, limit_reverse_motion: bool = False):
        self._name = "MotionMagicVelocityTorqueCurrentFOC"
        self.update_freq_hz: hertz = 100.0
        
        self.velocity = velocity
        """
        Target velocity to drive toward in rotations per second.  This can be changed
        on-the fly.
        """
        self.acceleration = acceleration
        """
        This is the absolute Acceleration to use generating the profile.  If this
        parameter is zero, the Acceleration persistent configuration parameter is used
        instead. Acceleration is in rotations per second squared.  If nonzero, the
        signage does not matter as the absolute value is used.
        """
        self.enable_foc = enable_foc
        """
        Set to true to use FOC commutation (requires Phoenix Pro), which increases peak
        power by ~15%. Set to false to use trapezoidal commutation.  FOC improves motor
        performance by leveraging torque (current) control.  However, this may be
        inconvenient for applications that require specifying duty cycle or voltage. 
        CTR-Electronics has developed a hybrid method that combines the performances
        gains of FOC while still allowing applications to provide duty cycle or voltage
        demand.  This not to be confused with simple sinusoidal control or phase voltage
        control which lacks the performance gains.
        """
        self.feed_forward = feed_forward
        """
        Feedforward to apply in torque current in Amperes.  User can use motor's kT to
        scale Newton-meter to Amperes.
        """
        self.slot = slot
        """
        Select which gains are applied by selecting the slot.  Use the configuration api
        to set the gain values for the selected slot before enabling this feature. Slot
        must be within [0,2].
        """
        self.override_coast_dur_neutral = override_coast_dur_neutral
        """
        Set to true to coast the rotor when output is zero (or within deadband).  Set to
        false to use the NeutralMode configuration setting (default). This flag exists
        to provide the fundamental behavior of this control when output is zero, which
        is to provide 0A (zero torque).
        """
        self.limit_forward_motion = limit_forward_motion
        """
        Set to true to force forward limiting.  This allows users to use other limit
        switch sensors connected to robot controller.  This also allows use of active
        sensors that require external power.
        """
        self.limit_reverse_motion = limit_reverse_motion
        """
        Set to true to force reverse limiting.  This allows users to use other limit
        switch sensors connected to robot controller.  This also allows use of active
        sensors that require external power.
        """

    @property
    def name(self) -> str:
        """
        Gets the name of this control request.

        :returns: Name of the control request
        :rtype: str
        """
        return self._name

    def __str__(self) -> str:
        ss = []
        ss.append("class: MotionMagicVelocityTorqueCurrentFOC")
        ss.append("velocity: " + str(self.velocity))
        ss.append("acceleration: " + str(self.acceleration))
        ss.append("enable_foc: " + str(self.enable_foc))
        ss.append("feed_forward: " + str(self.feed_forward))
        ss.append("slot: " + str(self.slot))
        ss.append("override_coast_dur_neutral: " + str(self.override_coast_dur_neutral))
        ss.append("limit_forward_motion: " + str(self.limit_forward_motion))
        ss.append("limit_reverse_motion: " + str(self.limit_reverse_motion))
        return "\n".join(ss)

    def _send_request(self, network: str, device_hash: int, cancel_other_requests: bool) -> StatusCode:
        """
        Sends this request out over CAN bus to the device for
        the device to apply.

        :param network: Network to send request over
        :type network: str
        :param device_hash: Device to send request to
        :type device_hash: int
        :param cancel_other_requests: True to cancel other requests
        :type cancel_other_requests: bool
        :returns: Status of the send operation
        :rtype: StatusCode
        """
        return StatusCode(Native.instance().c_ctre_phoenix6_RequestControlMotionMagicVelocityTorqueCurrentFOC(ctypes.c_char_p(bytes(network, 'utf-8')), device_hash, self.update_freq_hz, cancel_other_requests, self.velocity, self.acceleration, self.enable_foc, self.feed_forward, self.slot, self.override_coast_dur_neutral, self.limit_forward_motion, self.limit_reverse_motion))

    
    def with_velocity(self, new_velocity: rotations_per_second) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's velocity parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_velocity: Parameter to modify
        :type new_velocity: rotations_per_second
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.velocity = new_velocity
        return self
    
    def with_acceleration(self, new_acceleration: rotations_per_second_squared) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's acceleration parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_acceleration: Parameter to modify
        :type new_acceleration: rotations_per_second_squared
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.acceleration = new_acceleration
        return self
    
    def with_enable_foc(self, new_enable_foc: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's enable_foc parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_enable_foc: Parameter to modify
        :type new_enable_foc: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.enable_foc = new_enable_foc
        return self
    
    def with_feed_forward(self, new_feed_forward: ampere) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's feed_forward parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_feed_forward: Parameter to modify
        :type new_feed_forward: ampere
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.feed_forward = new_feed_forward
        return self
    
    def with_slot(self, new_slot: int) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's slot parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_slot: Parameter to modify
        :type new_slot: int
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.slot = new_slot
        return self
    
    def with_override_coast_dur_neutral(self, new_override_coast_dur_neutral: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's override_coast_dur_neutral parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_override_coast_dur_neutral: Parameter to modify
        :type new_override_coast_dur_neutral: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.override_coast_dur_neutral = new_override_coast_dur_neutral
        return self
    
    def with_limit_forward_motion(self, new_limit_forward_motion: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's limit_forward_motion parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_limit_forward_motion: Parameter to modify
        :type new_limit_forward_motion: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.limit_forward_motion = new_limit_forward_motion
        return self
    
    def with_limit_reverse_motion(self, new_limit_reverse_motion: bool) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Modifies this Control Request's limit_reverse_motion parameter and returns itself for
        method-chaining and easier to use request API.
    
        :param new_limit_reverse_motion: Parameter to modify
        :type new_limit_reverse_motion: bool
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.limit_reverse_motion = new_limit_reverse_motion
        return self

    def with_update_freq_hz(self, new_update_freq_hz: hertz) -> 'MotionMagicVelocityTorqueCurrentFOC':
        """
        Sets the period at which this control will update at.
        This is designated in Hertz, with a minimum of 20 Hz
        (every 50 ms) and a maximum of 1000 Hz (every 1 ms).

        If this field is set to 0 Hz, the control request will
        be sent immediately as a one-shot frame. This may be useful
        for advanced applications that require outputs to be
        synchronized with data acquisition. In this case, we
        recommend not exceeding 50 ms between control calls.

        :param new_update_freq_hz: Parameter to modify
        :type new_update_freq_hz: hertz
        :returns: Itself
        :rtype: MotionMagicVelocityTorqueCurrentFOC
        """
        self.update_freq_hz = new_update_freq_hz
        return self

    @property
    def control_info(self) -> dict:
        """
        Gets information about this control request.

        :returns: Dictonary of control parameter names and corresponding applied values
        :rtype: dict
        """
        control_info = {}
        control_info["name"] = self._name
        control_info["velocity"] = self.velocity
        control_info["acceleration"] = self.acceleration
        control_info["enable_foc"] = self.enable_foc
        control_info["feed_forward"] = self.feed_forward
        control_info["slot"] = self.slot
        control_info["override_coast_dur_neutral"] = self.override_coast_dur_neutral
        control_info["limit_forward_motion"] = self.limit_forward_motion
        control_info["limit_reverse_motion"] = self.limit_reverse_motion
        return control_info
